/* Copyright (C) 2000-2006 Lavtech.com corp. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
*/

#ifndef _UDM_HOST_H
#define _UDM_HOST_H

extern int             UdmHostLookup2(UDM_AGENT *,UDM_HOSTLIST *,UDM_CONN *);
extern int             UdmHostLookup(UDM_HOSTLIST *,UDM_CONN *);
extern void            UdmHostListFree(UDM_HOSTLIST *);
extern UDM_HOST_ADDR  *UdmHostFind(UDM_HOSTLIST *,const char *hostname);
extern void            UdmHostErrorReset(UDM_HOSTLIST *, const char *hostname);
extern void            UdmHostErrorIncrement(UDM_HOSTLIST *, const char *hostname);

#endif
